import * as d3 from 'd3';

let data = [
  {
    Title: 'Adaptation',
    Distributor: 'Sony Pictures',
    Genre: 'Comedy',
    Worldwide_Gross: 22498520,
    Rating: 91,
  },
  {
    Title: 'Air Bud',
    Distributor: 'Walt Disney Pictures',
    Genre: 'Comedy',
    Worldwide_Gross: 27555061,
    Rating: 45,
  },
  {
    Title: 'Air Force One',
    Distributor: 'Sony Pictures',
    Genre: 'Action',
    Worldwide_Gross: 315268353,
    Rating: 78,
  },
  {
    Title: 'Alex & Emma',
    Distributor: 'Warner Bros.',
    Genre: 'Drama',
    Worldwide_Gross: 15358583,
    Rating: 11,
  },
  {
    Title: 'Alexander',
    Distributor: 'Warner Bros.',
    Genre: 'Adventure',
    Worldwide_Gross: 167297191,
    Rating: 16,
  },
  {
    Title: 'Ali',
    Distributor: 'Sony Pictures',
    Genre: 'Drama',
    Worldwide_Gross: 84383966,
    Rating: 67,
  },
  {
    Title: 'Alice in Wonderland',
    Distributor: 'Walt Disney Pictures',
    Genre: 'Adventure',
    Worldwide_Gross: 1023291110,
    Rating: 51,
  },
  {
    Title: 'Alive',
    Distributor: 'Walt Disney Pictures',
    Genre: 'Adventure',
    Worldwide_Gross: 36299670,
    Rating: 71,
  },
  {
    Title: "All the King's Men",
    Distributor: 'Sony Pictures',
    Genre: 'Drama',
    Worldwide_Gross: 9521458,
    Rating: 11,
  },
  {
    Title: 'Amadeus',
    Distributor: 'Warner Bros.',
    Genre: 'Drama',
    Worldwide_Gross: 51973029,
    Rating: 96,
  },
];

function sumWorldwideGross(group) {
  return d3.sum(group, (d) => d.Worldwide_Gross);
}

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  // Group the data
  let groups = d3.rollup(
    data,
    sumWorldwideGross,
    (d) => d.Distributor,
    (d) => d.Genre,
  );

  // make root element
  let root = d3.hierarchy(groups);
  root.sum((d) => {
    console.log(d);
    return d[1];
  });

  // make tree layout
  let treeLayout = d3.tree().size([945, 275]);

  // pass root to tree layout
  treeLayout(root);

  const svg = d3
    .select(container)
    .selectAll('svg')
    .data([1])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  // Links
  svg
    .selectAll('line')
    .data(root.links())
    .join('line')
    .attr('x1', (d) => d.source.x)
    .attr('y1', (d) => d.source.y)
    .attr('x2', (d) => d.target.x)
    .attr('y2', (d) => d.target.y)
    .attr('fill', 'none')
    .attr('stroke', '#ccc')
    .attr('stroke-width', '1px');

  // Nodes
  svg
    .selectAll('circle')
    .data(root.descendants())
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 4)
    .attr('fill', 'steelblue')
    .attr('stroke', 'none');

  // Labels
  svg
    .selectAll('text.label')
    .data(root.descendants())
    .join('text')
    .attr('class', 'label')
    .attr('x', (d) => d.x)
    .attr('y', (d) => d.y - 10)
    .text((d) => d.data[0]);

  // Leaf count labels
  svg
    .selectAll('text.count-label')
    .data(root.descendants())
    .join('text')
    .attr('class', 'count-label')
    .attr('x', (d) => d.x)
    .attr('y', (d) => d.y + 20)
    .text((d) => (d.height > 0 ? '' : d.data[1]));
};
